/*
 *  MixPlan - Shuffle Planets Around
 *
 *  This program takes a XYPLAN.DAT file and shuffles planets around.
 *  That is, you'll get a map which has the same appearance, but in
 *  which planet Ids are assigned randomly. It should work with any
 *  ISO C compiler.
 *
 *  Coded 12/Feb/2003 by Stefan Reuther. Public Domain.
 */

#include <stdio.h>
#include <stdlib.h>

static char data[500][6];

int
main(int argc, char** argv)
{
    FILE* fp;
    int i, j;

    srand(time(0));
    if (argc != 2) {
        fprintf(stderr, "usage: %s xyplan.dat\n", argv[0]);
        return 1;
    }
    if (!(fp = fopen(argv[1], "rb+"))) {
        perror(argv[1]);
        return 1;
    }
    if (fread(data, sizeof data, 1, fp) != 1) {
        fprintf(stderr, "%s: read error\n", argv[1]);
        return 1;
    }
    for (i = 1; i < 500; ++i) {
        char buf[6];
        j = rand() % i;
        memcpy(buf, data[i], 6);
        memcpy(data[i], data[j], 6);
        memcpy(data[j], buf, 6);
    }
    fseek(fp, 0, SEEK_SET);
    if (fwrite(data, sizeof data, 1, fp) != 1) {
        fprintf(stderr, "%s: write error\n", argv[1]);
        return 1;
    }
    fclose(fp);
    puts("Map has been shuffled.");
    return 0;
}
